# aeclib
Open-source computational logic for global building codes and standards.

aeclib translates building code provisions into executable and testable logic.

## Project Status: Pre-Alpha
This package is currently in the foundation phase. We are securing the namespace and establishing the core architecture.

## Intent
The goal of aeclib is to provide a unified "Logic Layer" for the AEC industry to support automated compliance and computational design.

## License
Licensed under the Apache License 2.0.